@@ -29,7 +29,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=1,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is not enabled.
@@ -52,7 +52,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=23,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is not enabled.
@@ -76,7 +76,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is not enabled.
@@ -99,7 +99,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is not enabled.
@@ -121,7 +121,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is not enabled.
@@ -142,7 +142,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=13, esm_apps_updates=0,
                         have_esm_infra=True, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is enabled.
@@ -162,7 +162,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=13, esm_apps_updates=0,
                         have_esm_infra=True, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is enabled.
@@ -183,7 +183,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=True, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=10, hide_esm_messages=False),
+                        disabled_esm_apps_updates=10),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is enabled.
@@ -201,7 +201,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=15, esm_apps_updates=15,
                         have_esm_infra=True, have_esm_apps=True,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """
                 Expanded Security Maintenance for Infrastructure is enabled.
@@ -222,7 +222,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=15,
                         have_esm_infra=False, have_esm_apps=True,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """
                 Expanded Security Maintenance for Infrastructure is not enabled.
@@ -247,7 +247,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=1,
                         have_esm_infra=False, have_esm_apps=True,
                         disabled_esm_infra_updates=40,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """
                 Expanded Security Maintenance for Infrastructure is not enabled.
@@ -272,7 +272,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=1,
                         have_esm_infra=False, have_esm_apps=True,
                         disabled_esm_infra_updates=40,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """
                 Expanded Security Maintenance for Applications is enabled.
@@ -293,7 +293,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=40, hide_esm_messages=False),
+                        disabled_esm_apps_updates=40),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Infrastructure is not enabled.
@@ -316,7 +316,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 30 updates can be applied immediately.
@@ -334,7 +334,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 30 updates can be applied immediately.
@@ -352,7 +352,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=40, hide_esm_messages=False),
+                        disabled_esm_apps_updates=40),
             textwrap.dedent(
                 """\
                 30 updates can be applied immediately.
@@ -375,7 +375,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=40, hide_esm_messages=False),
+                        disabled_esm_apps_updates=40),
             textwrap.dedent(
                 """\
                 30 updates can be applied immediately.
@@ -393,7 +393,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=10,
-                        disabled_esm_apps_updates=40, hide_esm_messages=False),
+                        disabled_esm_apps_updates=40),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Applications is not enabled.
@@ -416,7 +416,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 0 updates can be applied immediately.
@@ -432,7 +432,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 1 update can be applied immediately.
@@ -449,7 +449,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 1 update can be applied immediately.
@@ -467,7 +467,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 0 updates can be applied immediately.
@@ -483,7 +483,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 Expanded Security Maintenance for Applications is not enabled.
@@ -504,7 +504,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 1 update can be applied immediately.
@@ -521,7 +521,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=False),
+                        disabled_esm_apps_updates=0),
             textwrap.dedent(
                 """\
                 1 update can be applied immediately.
@@ -529,94 +529,6 @@ class TestMotd(unittest.TestCase):
                 To see these additional updates run: apt list --upgradable
                 """))
 
-    @mock.patch("apt_check.is_lts_distro", return_value=True)
-    @mock.patch("apt_check.is_esm_distro", return_value=False)
-    def test_message_no_upgrades_lts_distro_with_esm_sources_hide_esm(
-        self, _m_is_esm, _m_is_lts
-    ):
-        self.assertEqual(
-            get_message(upgrades=0, security_updates=0,
-                        esm_infra_updates=0, esm_apps_updates=0,
-                        have_esm_infra=False, have_esm_apps=False,
-                        disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=True),
-            textwrap.dedent(
-                """\
-                0 updates can be applied immediately.
-                """))
-
-    @mock.patch("apt_check.is_lts_distro", return_value=True)
-    @mock.patch("apt_check.is_esm_distro", return_value=False)
-    def test_message_for_lts_distro_not_in_esm_mode_yet_hide_esm(
-        self, _m_is_esm, _m_is_lts
-    ):
-        self.assertEqual(
-            get_message(upgrades=30, security_updates=18,
-                        esm_infra_updates=0, esm_apps_updates=0,
-                        have_esm_infra=False, have_esm_apps=False,
-                        disabled_esm_infra_updates=10,
-                        disabled_esm_apps_updates=40, hide_esm_messages=True),
-            textwrap.dedent(
-                """\
-                30 updates can be applied immediately.
-                18 of these updates are standard security updates.
-                To see these additional updates run: apt list --upgradable
-                """))
-
-    @mock.patch("apt_check.is_lts_distro", return_value=True)
-    @mock.patch("apt_check.is_esm_distro", return_value=False)
-    def test_esm_infra_disabled_wih_pkgs_and_esm_apps_on_lts_distro_hide_esm(
-        self, _m_esm_distro, _m_is_lts
-    ):
-        self.assertEqual(
-            get_message(upgrades=30, security_updates=15,
-                        esm_infra_updates=0, esm_apps_updates=1,
-                        have_esm_infra=False, have_esm_apps=True,
-                        disabled_esm_infra_updates=40,
-                        disabled_esm_apps_updates=0, hide_esm_messages=True),
-            textwrap.dedent(
-                """
-                30 updates can be applied immediately.
-                15 of these updates are standard security updates.
-                To see these additional updates run: apt list --upgradable
-                """).lstrip())
-
-    @mock.patch("apt_check.get_distro_version", return_value="16.04")
-    @mock.patch("apt_check.is_lts_distro", return_value=True)
-    @mock.patch("apt_check.is_esm_distro", return_value=True)
-    def test_esm_infra_disabled_wih_pkgs_and_esm_apps_enabled_hide_esm(
-        self, _m_esm_distro, _m_is_lts, _m_distro_version
-    ):
-        self.assertEqual(
-            get_message(upgrades=30, security_updates=15,
-                        esm_infra_updates=0, esm_apps_updates=1,
-                        have_esm_infra=False, have_esm_apps=True,
-                        disabled_esm_infra_updates=40,
-                        disabled_esm_apps_updates=0, hide_esm_messages=True),
-            textwrap.dedent(
-                """
-                30 updates can be applied immediately.
-                15 of these updates are standard security updates.
-                To see these additional updates run: apt list --upgradable
-                """).lstrip())
-
-    @mock.patch("apt_check.is_lts_distro", return_value=True)
-    @mock.patch("apt_check.is_esm_distro", return_value=True)
-    def test_esm_infra_and_esm_apps_enabled_hide_esm(
-        self, _m_esm_distro, _m_is_lts
-    ):
-        self.assertEqual(
-            get_message(upgrades=30, security_updates=0,
-                        esm_infra_updates=15, esm_apps_updates=15,
-                        have_esm_infra=True, have_esm_apps=True,
-                        disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0, hide_esm_messages=True),
-            textwrap.dedent(
-                """
-                30 updates can be applied immediately.
-                To see these additional updates run: apt list --upgradable
-                """).lstrip())
-
 
 class TestGetDistro(unittest.TestCase):
     @mock.patch("os.path.exists", return_value=True)
